# ifndef yyRemoteAccess
# define yyRemoteAccess

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* RemoteAccess_Exit) ARGS ((void));

extern tTree TranslateRMA ARGS ((tTree stmt));

extern void BeginRemoteAccess ARGS ((void));
extern void CloseRemoteAccess ARGS ((void));

# endif
